var indexSectionsWithContent =
{
  0: "abcdefghijklmnoprstuvwxz",
  1: "abcdefghijlmnoprstuvw",
  2: "a",
  3: "abcdefghijlmnoprstuvw",
  4: "bdlmnopstuvxz",
  5: "kst",
  6: "abdefilmnrstuxz",
  7: "abcdefgilmnoprstuvw",
  8: "n"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "functions",
  4: "variables",
  5: "enums",
  6: "enumvalues",
  7: "properties",
  8: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Functions",
  4: "Variables",
  5: "Enumerations",
  6: "Enumerator",
  7: "Properties",
  8: "Pages"
};

